@@ -150,6 +150,22 @@ def test_init_keeps_specified_charset_when_json():
 def test_init_doesnt_add_default_content_type_with_bodyless_status():
     assert Response(status='204 No Content').content_type is None
 
+def test_content_type_supports_unicode():
+    content_type = u"text/html"
+    resp = Response()
+    resp.content_type = content_type
+    assert isinstance(resp.headers["Content-Type"], str)
+
+
+@pytest.mark.skipif("sys.version_info < (3, 0)")
+def test_content_type_not_binary():
+    content_type = b"text/html"
+    resp = Response()
+
+    with pytest.raises(TypeError):
+        resp.content_type = content_type
+
+
 def test_cookies():
     res = Response()
     # test unicode value
@@ -169,7 +185,7 @@ def test_unicode_cookies_error_raised():
         Response.set_cookie(
             res,
             'x',
-            text_(b'\N{BLACK SQUARE}', 'unicode_escape'))
+            text_(b'\\N{BLACK SQUARE}', 'unicode_escape'))
 
 def test_unicode_cookies_warning_issued():
     import warnings
@@ -182,7 +198,7 @@ def test_unicode_cookies_warning_issued():
         # Trigger a warning.
 
         res = Response()
-        res.set_cookie('x', text_(b'\N{BLACK SQUARE}', 'unicode_escape'))
+        res.set_cookie('x', text_(b'\\N{BLACK SQUARE}', 'unicode_escape'))
 
         assert len(w) == 1
         assert issubclass(w[-1].category, RuntimeWarning) is True
@@ -832,6 +848,7 @@ def test_set_cookie_expires_is_None_and_max_age_is_timedelta():
     assert val[2] == 'a=1'
     assert val[3].startswith('expires')
 
+@pytest.mark.filterwarnings('ignore:"expires" will be removed"')
 def test_set_cookie_expires_is_datetime_and_max_age_is_None():
     import datetime
     res = Response()
@@ -846,6 +863,7 @@ def test_set_cookie_expires_is_datetime_and_max_age_is_None():
     assert val[2] == 'a=1'
     assert val[3].startswith('expires')
 
+@pytest.mark.filterwarnings('ignore:"expires" will be removed"')
 def test_set_cookie_expires_is_timedelta_and_max_age_is_None():
     import datetime
     res = Response()
@@ -860,6 +878,7 @@ def test_set_cookie_expires_is_timedelta_and_max_age_is_None():
     assert val[2] == 'a=1'
     assert val[3].startswith('expires')
 
+@pytest.mark.filterwarnings('ignore:"expires" will be removed"')
 def test_set_cookie_expires_is_datetime_tz_and_max_age_is_None():
     import datetime
     res = Response()
